###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_ms_powerpoint_code_exec_vuln.nasl 1397 2009-04-03 14:21:24Z apr $
#
# Microsoft PowerPoint File Parsing Remote Code Execution Vulnerability (969136)
#
# Authors:
# Sharath S <sharaths@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800382);
  script_version("$Revision: 1.0 $");
  script_cve_id("CVE-2009-0556");
  script_bugtraq_id(34351);
  script_name(english:"Microsoft PowerPoint File Parsing Remote Code Execution Vulnerability (969136)");
  desc["english"] = "

  Overview: The host is installed with Microsoft PowerPoint and is prone to
  file parsing remote code execution vulnerability.

  Vulnerability Insight:
  This flaw is caused when powerpoint accesses an invalid object in memory
  while parsing a specially crafted powerpoint file.

  Impact:
  Successful exploitation will let the attacker execute arbitrary codes in the
  context of the application crafting a malicious powerpoint file.

  Impact Level: System/Application

  Affected Software/OS:
  MS PowerPoint 2000 Service Pack 3 and prior
  MS PowerPoint 2002 Service Pack 3 and prior
  MS PowerPoint 2003 Service Pack 3 and prior

  Fix: No solution or patch is available as on 07th April, 2009. Information
  regarding this issue will be updated once the solution details are available.
  For updates refer, http://office.microsoft.com/en-us/powerpoint/default.aspx

  Workaround:
  For workaround see the Suggested Actions mentioned.
  http://www.microsoft.com/technet/security/advisory/969136.mspx

  References:
  http://www.kb.cert.org/vuls/id/627331
  http://support.microsoft.com/kb/969136
  http://blogs.technet.com/srd/archive/2009/04/02/investigating-the-new-powerpoint-issue.aspx
  http://blogs.technet.com/mmpc/archive/2009/04/02/new-0-day-exploits-using-powerpoint-files.aspx

  CVSS Score:
    CVSS Base Score     : 9.3 (AV:N/AC:M/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score : 7.5
  Risk factor : High";

  script_description(english:desc["english"]);
  script_summary(english:"Check for the version of Microsoft PowerPoint");
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"Copyright (C) 2009 Intevation GmbH");
  script_family(english:"Windows");
  script_dependencies("secpod_ms_office_detection_900025.nasl",
                      "secpod_office_products_version_900032.nasl");
  script_require_keys("SMB/WindowsVersion");
  exit(0);
}


include("smb_nt.inc");
include("version_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

officeVer = get_kb_item("MS/Office/Ver");
if(officeVer =~ "^(9|10|11)\..*")
{
  # Grep for MS Office PowerPoint Version <= (9.0.8969, 10.0.6842 and 11.0.8227)
  ppVer = get_kb_item("SMB/Office/PowerPnt/Version");
  if(ppVer)
  {
    if(version_in_range(version:ppVer, test_version:"9.0", test_version2:"9.0.8969.0") ||
       version_in_range(version:ppVer, test_version:"10.0", test_version2:"10.0.6842.0")||
       version_in_range(version:ppVer, test_version:"11.0", test_version2:"11.0.8227.0")){
      security_hole(0);
    }
  }
}
