###############################################################################
# OpenVAS Vulnerability Test
# $Id: secpod_ms_excel_remote_code_exec_vuln.nasl 633 2009-03-17 18:20:09Z mar $
#
# Microsoft Excel Remote Code Execution Vulnerability (968272)
#
# Authors:
# Sujit Ghosal <sghosal@secpod.com>
#
# Copyright:
# Copyright (c) 2009 SecPod, http://www.secpod.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(900476);
  script_version("$Revision: 1.0 $");
  script_cve_id("CVE-2009-0238");
  script_bugtraq_id(33870);
  script_name(english:"Microsoft Excel Remote Code Execution Vulnerability (968272)");
  desc["english"] = "

  Overview: This host has installed Microsoft Excel and is prone to remote
  code execution vulnerability.

  Vulnerability Insight:
  A vulnerability exists while opening a specially crafted excel file which
  in triggers an access attempt on an invalid object causes remote code
  execution.

  Impact:
  Successful exploitation could execution of arbitrary codes on the remote
  system in the context of affected excel application.

  Impact Level: System

  Affected Software/OS:
  Microsoft Office Excel 2k  SP 3
  Microsoft Office Excel 2k2 SP 3
  Microsoft Office Excel 2k3 SP 3
  Microsoft Office Excel 2k7 SP 1

  Fix:
  Solution/Patch not available as on 17th March 2009. For further updates
  refer, http://office.microsoft.com/excel

  References:
  http://blogs.zdnet.com/security/?p=2658
  http://isc.sans.org/diary.html?storyid=5923
  http://securitytracker.com/alerts/2009/Feb/1021744.html
  http://www.microsoft.com/technet/security/advisory/968272.mspx

  CVSS Score:
    CVSS Base Score     : 9.3 (AV:N/AC:M/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score : 7.9
  Risk factor : High";

  script_description(english:desc["english"]);
  script_summary(english:"Check for the MS Office Excel file version");
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"Copyright (C) 2009 SecPod");
  script_family(english:"Windows : Microsoft Bulletins");
  script_dependencies("secpod_office_products_version_900032.nasl",
                      "secpod_ms_office_detection_900025.nasl");
  script_require_keys("SMB/WindowsVersion", "SMB/Office/Excel/Version");
  exit(0);
}


include("version_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

if(egrep(pattern:"^(9|10|11|12)\..*", string:get_kb_item("MS/Office/Ver")))
{
  excelVer = get_kb_item("SMB/Office/Excel/Version");
  if(!excelVer){
    exit(0);
  }

  if(version_in_range(version:excelVer, test_version:"9.0",
                      test_version2:"9.0.8974")){
    security_hole(0);
  }
  else if(version_in_range(version:excelVer, test_version:"10.0",
                           test_version2:"10.0.6850")){
    security_hole(0);
  }
  else if(version_in_range(version:excelVer, test_version:"11.0",
                           test_version2:"11.0.8237")){
    security_hole(0);
  }
  else if(version_in_range(version:excelVer, test_version:"12.0",
                           test_version2:"12.0.6331.5000")){
    security_hole(0);
  }
}
